unit Unit1;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, ExtCtrls, Grids;

type
  TForm1 = class(TForm)
    StringGrid1: TStringGrid;
    Panel1: TPanel;
    rgShortDateFormat: TRadioGroup;
    rgDecSeparator: TRadioGroup;
    rgLongDateFormat: TRadioGroup;
    procedure FormCreate(Sender: TObject);
    procedure rgShortDateFormatClick(Sender: TObject);
    procedure rgLongDateFormatClick(Sender: TObject);
    procedure rgDecSeparatorClick(Sender: TObject);
    procedure FormResize(Sender: TObject);
  private
    procedure ShowCurrent(SelCol, SelRow: integer);
    { Private declarations }
  public
    { Public declarations }
  end;

var
  Form1: TForm1;

implementation

{$R *.DFM}

var
  WinShortDateFormat, WinLongDateFormat: string;
  WinDecimalSep: char;

// Show initial formats, given by Windows' settings
procedure TForm1.FormCreate(Sender: TObject);
begin
  // Save Windows settings (in case needed later on...)
  WinShortDateFormat := ShortDateFormat;
  WinLongDateFormat := LongDateFormat;
  WinDecimalSep := DecimalSeparator;
  // Show headers, Windows settings, date, decimal number
  with StringGrid1 do begin
    Cells[0, 1] := ' ShortDateFormat';
    Cells[0, 2] := ' Short Date';
    Cells[0, 3] := ' LongDateFormat';
    Cells[0, 4] := ' Long Date';
    Cells[0, 5] := ' DecimalSeparator';
    Cells[0, 6] := ' 5/4 equals...';
    Cells[1, 0] := ' Windows settings';
    Cells[1, 1] := WinShortDateFormat;
    // ddddd = use format given by the ShortDateFormat global variable
    Cells[1, 2] := FormatDateTime('ddddd', Now);
    Cells[1, 3] := WinLongDateFormat;
    // dddddd = use format given by the LongDateFormat global variable
    Cells[1, 4] := FormatDateTime('dddddd', Now);
    Cells[1, 5] := WinDecimalSep;
    Cells[1, 6] := FloatToStr(5/4);
    Col := 1;
    Row := 2;
  end;
  // Show current settings
  ShowCurrent(1, 2);
end;

// OnClick event handler of radiogroup for selection of short dateformat
procedure TForm1.rgShortDateFormatClick(Sender: TObject);
begin
  if rgShortDateFormat.ItemIndex = 0 then  // use Windows setting
    ShortDateFormat := WinShortDateFormat
  else                                     // use custom setting
    ShortDateFormat := rgShortDateFormat.Items[rgShortDateFormat.ItemIndex];
  ShowCurrent(2, 2);
end;

// OnClick event handler of radiogroup for selection of long dateformat
procedure TForm1.rgLongDateFormatClick(Sender: TObject);
begin
  if rgLongDateFormat.ItemIndex = 0 then  // use Windows setting
    LongDateFormat := WinLongDateFormat
  else                                    // use custom setting
    LongDateFormat := rgLongDateFormat.Items[rgLongDateFormat.ItemIndex];
  ShowCurrent(2, 4);
end;

// OnClick event handler of radiogroup for selection of decimal separator
procedure TForm1.rgDecSeparatorClick(Sender: TObject);
begin
  if rgDecSeparator.ItemIndex = 0 then  // use Windows setting
    DecimalSeparator := WinDecimalSep
  else                                  // use custom setting
    DecimalSeparator := rgDecSeparator.Items[rgDecSeparator.ItemIndex][1];
  ShowCurrent(2, 6);
end;

// Show current format settings
procedure TForm1.ShowCurrent(SelCol, SelRow: integer);
begin
  with StringGrid1 do begin
    Cells[2, 0] := ' Current settings';
    Cells[2, 1] := ShortDateFormat;
    // ddddd = use format given by the ShortDateFormat global variable
    Cells[2, 2] := FormatDateTime('ddddd', Now);
    Cells[2, 3] := LongDateFormat;
    // dddddd = use format given by the LongDateFormat global variable
    Cells[2, 4] := FormatDateTime('dddddd', Now);
    Cells[2, 5] := DecimalSeparator;
    Cells[2, 6] := FloatToStr(5/4);
    // Hilight a cell to draw attention
    Col := SelCol;
    Row := SelRow;
  end;
end;


procedure TForm1.FormResize(Sender: TObject);
begin
  if Height < 380 then Height := 380;
  if Width < 580 then Width := 580;
end;

end.
